chemcoord.zmat\_functions.apply\_grad\_cartesian\_tensor
========================================================

.. currentmodule:: chemcoord.zmat_functions

.. autofunction:: apply_grad_cartesian_tensor